Language

Enum Language 

pub enum Language {
Show 71 variants Zho, Epo, Eng, Rus, Cmn, Spa, Por, Ita, Ben, Fra, Deu, Ukr, Kat, Ara, Hin, Jpn, Heb, Yid, Pol, Amh, Jav, Kor, Nob, Dan, Swe, Fin, Tur, Nld, Hun, Ces, Ell, Bul, Bel, Mar, Kan, Ron, Slv, Hrv, Srp, Mkd, Lit, Lav, Est, Tam, Vie, Urd, Tha, Guj, Uzb, Pan, Aze, Ind, Tel, Pes, Mal, Ori, Mya, Nep, Sin, Khm, Tuk, Aka, Zul, Sna, Afr, Lat, Slk, Cat, Tgl, Hye, Cym,
}

Variants



Zho



Epo



Eng



Rus



Cmn



Spa



Por



Ita



Ben



Fra



Deu



Ukr



Kat



Ara



Hin



Jpn



Heb



Yid



Pol



Amh



Jav



Kor



Nob



Dan



Swe



Fin



Tur



Nld



Hun



Ces



Ell



Bul



Bel



Mar



Kan



Ron



Slv



Hrv



Srp



Mkd



Lit



Lav



Est



Tam



Vie



Urd



Tha



Guj



Uzb



Pan



Aze



Ind



Tel



Pes



Mal



Ori



Mya



Nep



Sin



Khm



Tuk



Aka



Zul



Sna



Afr



Lat



Slk



Cat



Tgl



Hye



Cym

Implementations

Source

impl Language

pub fn code(&self) -> &'static str

pub fn from_code<S: AsRef<str>>(code: S) -> Option<Language>